@@ -85,37 +85,11 @@ sub _PushDependency
 	    );
 
 	if( scalar @{ $self->{'list'} } > ( $RT::DependenciesLimit || 1000 ) ) {
-		RTx::Shredder::Exception->throw( <<END
-Dependecies list have reach its limit.
-See \$RT::DependenciesLimit in RTx::Shredder docs.
-END
-);
+		RTx::Shredder::Exception->throw( "Dependencies list overflow" );
 	}
 	return;
 }
 
-=head2 List
-
-
-=cut
-
-sub List
-{
-	my $self = shift;
-	my %args = (
-		WithFlags => undef,
-		WithoutFlags => undef,
-		@_
-	);
-
-	my $wflags = delete $args{'WithFlags'};
-	my $woflags = delete $args{'WithoutFlags'};
-
-	return grep !defined( $wflags ) || ($_->Flags & $wflags) == $wflags,
-	         grep !defined( $woflags ) || !($_->Flags & $woflags),
-		   @{ $self->{'list'} };
-}
-
 =head2 Wipeout
 
 Goes thourgh collection of RTx::Shredder::Dependency objects and wipeout target object
@@ -135,11 +109,14 @@ sub Wipeout
 		@_
 	);
 
-	my @deps = $self->List( WithFlags => (delete $args{'WithFlags'} || 0) | DEPENDS_ON,
-			        WithoutFlags => delete $args{'WithoutFlags'},
-			      );
+	my $wflags = delete $args{'WithFlags'};
+	my $woflags = delete $args{'WithoutFlags'};
+	my $deps = $self->{'list'};
 
-	foreach my $d ( @deps ) {
+	foreach my $d ( @{ $deps } ) {
+		next unless( $d->Flags & DEPENDS_ON );
+		next if( defined( $wflags ) && !$d->Flags & $wflags );
+		next if( defined( $woflags ) && $d->Flags & $woflags );
 		my $o = $d->TargetObj;
 		$o->Wipeout( %args );
 	}
@@ -156,11 +133,14 @@ sub ValidateRelations
 		@_
 	);
 
-	my @deps = $self->List( WithFlags => (delete $args{'WithFlags'} || 0) | RELATES,
-			        WithoutFlags => delete $args{'WithoutFlags'},
-			      );
+	my $wflags = delete $args{'WithFlags'};
+	my $woflags = delete $args{'WithoutFlags'};
+	my $deps = $self->{'list'};
 
-	foreach my $d ( @deps ) {
+	foreach my $d ( @{ $deps } ) {
+		next unless( $d->Flags & RELATES );
+		next if( defined( $wflags ) && !$d->Flags & $wflags );
+		next if( defined( $woflags ) && $d->Flags & $woflags );
 		my $o = $d->TargetObj;
 		$o->ValidateRelations( %args );
 	}
