@@ -6,7 +6,6 @@ use RTx::Shredder::Exceptions;
 
 our %FlagDescs = (
 	1	=> 'depends on',
-	4	=> 'relates with',
 );
 
 
@@ -74,12 +73,14 @@ sub FlagsAsString
 
 sub BaseObj
 {
-	return $_[0]->Object( Type => 'Base' );
+	my $self = shift;
+	return $self->Object( Type => 'Base' );
 }
 
 sub TargetObj
 {
-	return $_[0]->Object( Type => 'Target' );
+	my $self = shift;
+	return $self->Object( Type => 'Target' );
 }
 
 sub Object
