@@ -5,20 +5,16 @@ use RTx::Shredder::Constants;
 use RTx::Shredder::Exceptions;
 use RTx::Shredder::Dependencies;
 
-sub Dependencies
+sub __DependsOn
 {
 	my $self = shift;
 	my %args = (
 			Shredder => undef,
-			Flags => DEPENDS_ON,
+			Dependencies => undef,
 			@_,
 		   );
-
-	unless( $self->id ) {
-		RTx::Shredder::Exception->throw('Object is not loaded');
-	}
-
-	my $deps = RTx::Shredder::Dependencies->new();
+	my $deps = $args{'Dependencies'};
+	my $list = [];
 
 # Scrips
 	my $objs = RT::Scrips->new( $self->CurrentUser );
@@ -30,8 +26,23 @@ sub Dependencies
 			Shredder => $args{'Shredder'}
 		);
 
-	return $deps;
+	return $self->SUPER::__DependsOn( %args );
 }
 
+sub __Relates
+{
+	my $self = shift;
+	my %args = (
+			Shredder => undef,
+			Dependencies => undef,
+			@_,
+		   );
+	my $deps = $args{'Dependencies'};
+	my $list = [];
+
+# TODO: Check here for exec module
+
+	return $self->SUPER::__Relates( %args );
+}
 
 1;
